@@ -13,6 +13,7 @@ class CRFConfig:
         bias: bool = True,
         window_size: int = 2,
         suffix_len: tuple = (2,2),
+        embedding_n_similar: int = 3,
         context_feature_layers: list = DEFAULT_LAYERS,
         context_feature_extractors: list = DEFAULT_EXTRACTORS,
         feature_layers: list = DEFAULT_LAYERS,
@@ -32,3 +33,4 @@ class CRFConfig:
         self.bias = bias
         self.window_size = window_size
         self.suffix_len = suffix_len
+        self.embedding_n_similar = embedding_n_similar
